==> asksuite-core-1.0.57.tgz: package/omnibees.crawler.js <==
const cheerio = require('cheerio');
const puppeteer = require('puppeteer');

require('datejs');
let TurndownService = require('turndown');
let PromiseBlue = require('bluebird');


function replace(str) {
    return str.replace(new RegExp('\t', 'g'), "")
}


function getPosition(string, subString, index) {
    return string.split(subString, index).join(subString).length;
}

function getNumber(str) {
    let regex = /\d+/g;
    let matches = str.match(regex);


    return matches[0];
}

function parse(parseData) {

    let day = parseData.substring(0, 2);
    let month = parseData.substring(2, 4);
    let year = parseData.substring(4, 8);

    return new Date(year, month, day)
}

function cleanArray(actual) {
    let newArray = new Array();
    for (let i = 0; i < actual.length; i++) {
        if (actual[i]) {
            newArray.push(actual[i]);
        }
    }
    return newArray;
}


async function test(browser, url, linkDetails){

    let x = null;

    try{

        let descriptionTab = await browser.newPage({privateTab: false});

        await descriptionTab.setRequestInterception(true);
        descriptionTab.on('request', request => {
            if (request.resourceType() === 'image' || request.resourceType() === 'font' || request.resourceType() === 'stylesheet' ) {
                request.abort();
            }
            else {
                request.continue();
            }

        });
        console.log(url+linkDetails);
        await descriptionTab.goto(url+linkDetails+"&lang=pt-BR", {timeout: 20000});


        await descriptionTab.waitForSelector('body');
        console.log("body existe");


        let newHtmlTag = await descriptionTab.evaluate(function (selector) {
            const selectorHtml = document.querySelector(selector);
            return selectorHtml.innerHTML
        }, 'body'); // returns innerHTML of first matching selector for class "main"

         x = cheerio.load(newHtmlTag);

    }catch (error) {
        console.log(error);
        console.log("erro na tab");
    }

    return x;
}

async function navigateWebsite(id, checkin, checkout, adultos, criancas ) {



    return new Promise(async (resolve, reject) => {
        const browser = await puppeteer.launch({headless: true, args: ['--no-sandbox', '--disable-setuid-sandbox']});
        try {

            const mainTab = await browser.newPage();

            // Document, Stylesheet, Image, Media, Font, Script, TextTrack, XHR, Fetch, EventSource, WebSocket, Manifest, Other.
            await mainTab.setRequestInterception(true);
            mainTab.on('request', request => {
                if (request.resourceType() === 'image' || request.resourceType() === 'font' || request.resourceType() === 'stylesheet' ) {
                    request.abort();
                }
                else {
                    request.continue();
                }

            });

            let url = "https://myreservations.omnibees.com";

            let ages = "-";
            if (criancas && parseInt(criancas) > 0){
                ages = "";
                for (let i =0; i < criancas; i++){
                    ages += "1;"
                }

                ages = ages.substring(0, ages.length-1);
            }

            let urlBuild = `${url}/default.aspx?q=${id}&lang=pt-BR&diff=false&CheckIn=${checkin}&CheckOut=${checkout}&Code=&group_code=&loyality_card=&NRooms=1&ad=${adultos}&ch=${criancas}&ag=${ages}`


            console.log(urlBuild);

            await mainTab.goto(urlBuild, {timeout: 20000});

            await mainTab.waitForSelector('.bestPriceTextColor', {timeout: 20000})


            const htmlTag = await mainTab.evaluate(function (selector) {
                const selectorHtml = document.querySelector(selector);
                return selectorHtml.innerHTML
            }, 'body'); // returns innerHTML of first matching selector for class "main"


            // console.log(htmlTag.result.value);

            let $ = cheerio.load(htmlTag);
            let promise = null;

            let rooms = [];


            let puhs = [];
            let itens = await $(".roomName").each(async (index, item) => {await puhs.push( item)} );



                PromiseBlue.map(puhs, async (tdx) => {

                    let room = new HotelRoom();

                    tdx = $(tdx);

                    console.log(tdx.find('.excerpt > h5').text());
                    console.log(tdx.find('h6.bestPriceTextColor').text());

                    room.name = replace(tdx.find('.excerpt > h5').text());
                    room.price = replace(tdx.find('h6.bestPriceTextColor').text());

                    let date1 = parse(checkin);
                    let date2 = parse(checkout);

                    let diffDays = parseInt((date2 - date1) / (1000 * 60 * 60 * 24));

                    console.log(diffDays);

                    let tempPrice = parseFloat(room.price.replace("R$", '').replace(".", "",).replace(",", "."));



                    if (!isNaN(tempPrice)){
                        room.total = "R$ " + ((tempPrice * diffDays).toFixed(2)).replace(".", ",");

                        tdx.find('.slide > a > img').each((index, itemAmenite) => {
                            room.images.unshift(url + $(itemAmenite).attr('src'));
                        });

                        if (room.images) {
                            room.mainPhoto = room.images[0];
                        }

                        let linkDetails = replace(tdx.find('.excerpt > h5 > a ').attr('href'));
                        linkDetails = linkDetails.substring(0, getPosition(linkDetails, '&', 2));

                        let element = await test(browser, url, linkDetails);

                        if (element){
                            room.amenites = [];
                            room.amountAdults = 0;
                            room.amountKids = 0;

                            let turndownService = new TurndownService();

                            let descriptionComplete = element('.roomDescription').html();
                            // let description = descriptionComplete.replace(new RegExp("\n", 'g'), "").replace("Descrição", "").trim();
                            let description = turndownService.turndown(descriptionComplete);
                            room.description = description.replace("### Descrição\n\n", "");

                            let data = element('.room_amenities').find('p').text();
                            let elements = data.split(".");

                            elements.forEach(item => {
                                //remover primeira tag: "Serviços Gerais"
                                let amenities = item.substring(item.indexOf(':') + 1, item.length);

                                amenities.split(",").forEach(amenite => {
                                    if (amenite && amenite.trim() != '') {
                                        room.amenites.push(amenite.trim());
                                    }

                                })
                            });
                        }else{
                            room = null;
                        }

                        return room;
                    }else{
                        return null;
                    }

                }, {concurrency: 5}).then(async rooms => {

                    // console.log(rooms)
                    rooms = cleanArray(rooms);

                    if (rooms && rooms.length > 0) {

                        console.log(rooms);

                        let obj = {
                            data: rooms,
                            url: urlBuild,
                        };

                        resolve(obj);

                    } else {


                        let msg = $('.info-message > h2').text().replace(new RegExp('\n', 'g'), '').replace("Alterar datas", "").trim()

                        let obj = {
                            message: replace(msg)
                        };


                        reject(obj);
                    }

                    await browser.close()
                })


        } catch (err) {

            console.log("caiu aqui no erro");

            console.log(err);

            browser.close();
            reject(err);
        }
    })

}
// //

// https://myreservations.omnibees.com/default.aspx?q=5307&diff=false&CheckIn=25022018&CheckOut=26022018&Code=&group_code=&loyality_card=&NRooms=1&ad=2&ch=0&ag=-
// https://myreservations.omnibees.com/default.aspx?q=5307&diff=false&CheckIn=25022018&CheckOut=26022018&Code=&group_code=&loyality_card=&NRooms=1&ad=2&ch=0&ag=-

//
navigateWebsite(1798, '10052018', '11052018', 2, 0).then(data => {
    console.log("sucesso")
}).catch(error => {
    console.log("caiu aqui");
    console.log(error.message);
});


// navigateWebsite(1798, '10052018', '11052018', 2, 0).then(data => {
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui");
//     console.log(error.message);
// });



class HotelRoom {

    constructor() {
        this.amenites = new Array();
        this.images = new Array();
    }

}


module.exports = {search: navigateWebsite};

==> asksuite-core-1.0.58.tgz: package/omnibees.crawler.js <==
const cheerio = require('cheerio');
const puppeteer = require('puppeteer');

require('datejs');
let TurndownService = require('turndown');
let PromiseBlue = require('bluebird');


function replace(str) {
    return str.replace(new RegExp('\t', 'g'), "")
}


function getPosition(string, subString, index) {
    return string.split(subString, index).join(subString).length;
}

function getNumber(str) {
    let regex = /\d+/g;
    let matches = str.match(regex);


    return matches[0];
}

function parse(parseData) {

    let day = parseData.substring(0, 2);
    let month = parseData.substring(2, 4);
    let year = parseData.substring(4, 8);

    return new Date(year, month, day)
}

function cleanArray(actual) {
    let newArray = new Array();
    for (let i = 0; i < actual.length; i++) {
        if (actual[i]) {
            newArray.push(actual[i]);
        }
    }
    return newArray;
}


async function test(browser, url, linkDetails){

    let x = null;

    try{

        let descriptionTab = await browser.newPage({privateTab: false});

        await descriptionTab.setRequestInterception(true);
        descriptionTab.on('request', request => {
            if (request.resourceType() === 'image' || request.resourceType() === 'font' || request.resourceType() === 'stylesheet' ) {
                request.abort();
            }
            else {
                request.continue();
            }

        });
        console.log(url+linkDetails);
        await descriptionTab.goto(url+linkDetails+"&lang=pt-BR", {timeout: 20000});


        await descriptionTab.waitForSelector('body');
        console.log("body existe");


        let newHtmlTag = await descriptionTab.evaluate(function (selector) {
            const selectorHtml = document.querySelector(selector);
            return selectorHtml.innerHTML
        }, 'body'); // returns innerHTML of first matching selector for class "main"

         x = cheerio.load(newHtmlTag);

    }catch (error) {
        console.log(error);
        console.log("erro na tab");
    }

    return x;
}

async function navigateWebsite(id, checkin, checkout, adultos, criancas ) {



    return new Promise(async (resolve, reject) => {
        const browser = await puppeteer.launch({headless: true, args: ['--no-sandbox', '--disable-setuid-sandbox']});
        try {

            const mainTab = await browser.newPage();

            // Document, Stylesheet, Image, Media, Font, Script, TextTrack, XHR, Fetch, EventSource, WebSocket, Manifest, Other.
            await mainTab.setRequestInterception(true);
            mainTab.on('request', request => {
                if (request.resourceType() === 'image' || request.resourceType() === 'font' || request.resourceType() === 'stylesheet' ) {
                    request.abort();
                }
                else {
                    request.continue();
                }

            });

            let url = "https://myreservations.omnibees.com";

            let ages = "-";
            if (criancas && parseInt(criancas) > 0){
                ages = "";
                for (let i =0; i < criancas; i++){
                    ages += "1;"
                }

                ages = ages.substring(0, ages.length-1);
            }

            let urlBuild = `${url}/default.aspx?q=${id}&lang=pt-BR&diff=false&CheckIn=${checkin}&CheckOut=${checkout}&Code=&group_code=&loyality_card=&NRooms=1&ad=${adultos}&ch=${criancas}&ag=${ages}`


            console.log(urlBuild);

            await mainTab.goto(urlBuild, {timeout: 20000});

            await mainTab.waitForSelector('.bestPriceTextColor, .info-message', {timeout: 20000})


            const textContent = await mainTab.evaluate(() => {
                if ( document.querySelector('.info-message > h2')){
                    return    document.querySelector('.info-message > h2').textContent;
                }else{
                    return null;
                }

            });
            if (textContent != ""){
                reject({message: textContent});
            }

            const htmlTag = await mainTab.evaluate(function (selector) {
                const selectorHtml = document.querySelector(selector);
                return selectorHtml.innerHTML
            }, 'body'); // returns innerHTML of first matching selector for class "main"


            // console.log(htmlTag.result.value);

            let $ = cheerio.load(htmlTag);
            let promise = null;

            let rooms = [];


            let puhs = [];
            let itens = await $(".roomName").each(async (index, item) => {await puhs.push( item)} );



                PromiseBlue.map(puhs, async (tdx) => {

                    let room = new HotelRoom();

                    tdx = $(tdx);

                    console.log(tdx.find('.excerpt > h5').text());
                    console.log(tdx.find('h6.bestPriceTextColor').text());

                    room.name = replace(tdx.find('.excerpt > h5').text());
                    room.price = replace(tdx.find('h6.bestPriceTextColor').text());

                    let date1 = parse(checkin);
                    let date2 = parse(checkout);

                    let diffDays = parseInt((date2 - date1) / (1000 * 60 * 60 * 24));

                    console.log(diffDays);

                    let tempPrice = parseFloat(room.price.replace("R$", '').replace(".", "",).replace(",", "."));



                    if (!isNaN(tempPrice)){
                        room.total = "R$ " + ((tempPrice * diffDays).toFixed(2)).replace(".", ",");

                        tdx.find('.slide > a > img').each((index, itemAmenite) => {
                            room.images.unshift(url + $(itemAmenite).attr('src'));
                        });

                        if (room.images) {
                            room.mainPhoto = room.images[0];
                        }

                        let linkDetails = replace(tdx.find('.excerpt > h5 > a ').attr('href'));
                        linkDetails = linkDetails.substring(0, getPosition(linkDetails, '&', 2));

                        let element = await test(browser, url, linkDetails);

                        if (element){
                            room.amenites = [];
                            room.amountAdults = 0;
                            room.amountKids = 0;

                            let turndownService = new TurndownService();

                            let descriptionComplete = element('.roomDescription').html();
                            // let description = descriptionComplete.replace(new RegExp("\n", 'g'), "").replace("Descrição", "").trim();
                            let description = turndownService.turndown(descriptionComplete);
                            room.description = description.replace("### Descrição\n\n", "");

                            let data = element('.room_amenities').find('p').text();
                            let elements = data.split(".");

                            elements.forEach(item => {
                                //remover primeira tag: "Serviços Gerais"
                                let amenities = item.substring(item.indexOf(':') + 1, item.length);

                                amenities.split(",").forEach(amenite => {
                                    if (amenite && amenite.trim() != '') {
                                        room.amenites.push(amenite.trim());
                                    }

                                })
                            });
                        }else{
                            room = null;
                        }

                        return room;
                    }else{
                        return null;
                    }

                }, {concurrency: 5}).then(async rooms => {

                    // console.log(rooms)
                    rooms = cleanArray(rooms);

                    if (rooms && rooms.length > 0) {

                        console.log(rooms);

                        let obj = {
                            data: rooms,
                            url: urlBuild,
                        };

                        resolve(obj);

                    } else {


                        let msg = $('.info-message > h2').text().replace(new RegExp('\n', 'g'), '').replace("Alterar datas", "").trim()

                        let obj = {
                            message: replace(msg)
                        };


                        reject(obj);
                    }

                    await browser.close()
                })


        } catch (err) {

            console.log("caiu aqui no erro");

            console.log(err);

            browser.close();
            reject(err);
        }
    })

}
// //

// https://myreservations.omnibees.com/default.aspx?q=5307&diff=false&CheckIn=25022018&CheckOut=26022018&Code=&group_code=&loyality_card=&NRooms=1&ad=2&ch=0&ag=-
// https://myreservations.omnibees.com/default.aspx?q=5307&diff=false&CheckIn=25022018&CheckOut=26022018&Code=&group_code=&loyality_card=&NRooms=1&ad=2&ch=0&ag=-

// //
// navigateWebsite(5409, '20032018', '21032018', 2, 0).then(data => {
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui");
//     console.log(error.message);
// });


// navigateWebsite(1798, '10052018', '11052018', 2, 0).then(data => {
//     console.log("sucesso")
// }).catch(error => {
//     console.log("caiu aqui");
//     console.log(error.message);
// });



class HotelRoom {

    constructor() {
        this.amenites = new Array();
        this.images = new Array();
    }

}


module.exports = {search: navigateWebsite};
